<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:set="http://www.etech.cz/XMLSchema/sim/setup.xsd">

	<xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

	<xsl:include href="template.xsl"/>

	<xsl:template match="set:Root">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="index.css" />
				<script type="text/javascript" src="setup.js"></script>
				<title><xsl:call-template name="title"/></title>
			</head>
			<body onLoad="InitPulses();SetRefresh(getInverter);validateProtocol();">
				<input type="hidden" id="refresh_rate" value="3" />
				<div id="container">
					<div id="min_height"></div>
					<div id="sidebar">
						<div id="sidebar-content">
							<div id="logo">
								<div id="logo_trans"/>
							</div>
							<div id="menu">
								<xsl:apply-templates select="Agent/Menu"/>
							</div>
							<div id="submit_area">
								<input type="button" class="input_auto" onClick="return SetInvertersAndMeasurement(false);">
									<xsl:attribute name="value"><xsl:value-of select="$lg/s[289]"/></xsl:attribute>
								</input>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
					<div id="main-div">
						<div id="main-content">
							<div id="top_area">
							  <div id="dev_name"><xsl:value-of select="Agent/DeviceName"/></div>
							  <div id="caption"><xsl:value-of select="$lg/s[206]"/></div>
							</div>
							<div id="content">
								<div class="column_left">
									<xsl:apply-templates select="InverterSet" mode="Inverter"/>
								</div>
								<div class="column_right">
									<xsl:apply-templates select="InverterSet" mode="Inverter3"/>
								</div>
								<div class="column_left">
									<xsl:apply-templates select="InverterSet" mode="Inverter2"/>
									<xsl:apply-templates select="Electrometer"/>
								</div>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
				</div>          
				<div id="bottom-contact">
					<xsl:apply-templates select="Agent/Contact"/>
				</div>
			</body>
		</html>
	</xsl:template>

	<!-- TEMPLATE -->

 	<xsl:template name="Protocol">
  	<xsl:param name="prot"/>
		<select onchange="InverterModified();validateProtocol();">
			<xsl:attribute name="id"><xsl:value-of select="name($prot)"/></xsl:attribute>
			<option value="-1">
				<xsl:if test="$prot=-1">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				- - - -	
			</option>
			<xsl:if test="string-length(name($prot)) = 8">
				<option value="0">
					<xsl:if test="$prot=0">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					AEG
				</option>
			</xsl:if>
			<option value="11">
				<xsl:if test="$prot=11">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Power-One (Aurora)
			</option>
			<option value="17">
				<xsl:if test="$prot=17">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Carlo Gavazzi
			</option>
			<option value="22">
				<xsl:if test="$prot=22">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Conext
			</option>
			<option value="10">
				<xsl:if test="$prot=10">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Danfoss
			</option>
			<option value="6">
				<xsl:if test="$prot=6">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Delta
			</option>
			<option value="24">
				<xsl:if test="$prot=24">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Diehl
			</option>
			<xsl:if test="ETInv=1">
				<option value="19">
					<xsl:if test="$prot=19">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					Etech	
				</option>
			</xsl:if>
			<xsl:if test="string-length(name($prot)) = 8">
				<option value="1">
					<xsl:if test="$prot=1">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					Fronius	
				</option>
			</xsl:if>
			<option value="15">
				<xsl:if test="$prot=15">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Kaco
			</option>
			<option value="21">
				<xsl:if test="$prot=21">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				KOSTAL
			</option>
			<option value="26">
				<xsl:if test="$prot=26">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Mastervolt
			</option>
			<option value="14">
				<xsl:if test="$prot=14">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Omron
			</option>
			<option value="23">
				<xsl:if test="$prot=23">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				POWER-TRAP
			</option>
<!--								
			<option value="13">
				<xsl:if test="$prot=13">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Pesos
			</option>
-->								
			<option value="27">
				<xsl:if test="$prot=27">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Refusol
			</option>
			<xsl:if test="string-length(name($prot)) = 8">
				<option value="9">
					<xsl:if test="$prot=9">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					Riello UPS
				</option>
			</xsl:if>
			<xsl:if test="string-length(name($prot)) = 8">
				<option value="7">
					<xsl:if test="$prot=7">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					Schneider (SunEzy)
				</option>
			</xsl:if>
			<option value="20">
				<xsl:if test="$prot=20">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Siemens
			</option>
			<option value="12">
				<xsl:if test="$prot=12">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Siliken
			</option>
			<option value="2">
				<xsl:if test="$prot=2">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				SMA (SMA-Net)
			</option>
			<option value="3">
				<xsl:if test="$prot=3">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				SMA (Sunny-Net)
			</option>
			<option value="5">
				<xsl:if test="$prot=5">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				SolarMax
			</option>
			<option value="25">
				<xsl:if test="$prot=25">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Studer Innotec
			</option>
			<option value="4">
				<xsl:if test="$prot=4">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Sungrow
			</option>
			<xsl:if test="string-length(name($prot)) = 8">
				<option value="8">
					<xsl:if test="$prot=8">
						<xsl:attribute name="selected">selected</xsl:attribute>
					</xsl:if>
					Sunville
				</option>
			</xsl:if>
			<option value="16">
				<xsl:if test="$prot=16">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Vacon
			</option>
			<option value="18">
				<xsl:if test="$prot=18">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				Xantrex
			</option>
<!-- Posledni je 27 (Refusol) -->												
		</select>
  </xsl:template>

 	<xsl:template name="BaudRate">
  	<xsl:param name="baud"/>
		<select onchange="InverterModified();">
			<xsl:attribute name="id"><xsl:value-of select="name($baud)"/></xsl:attribute>
			<option value="0">
				<xsl:if test="baud=0">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				300
			</option>
			<option value="1">
				<xsl:if test="$baud=1">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				600
			</option>
			<option value="2">
				<xsl:if test="$baud=2">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				1200
			</option>
			<option value="3">
				<xsl:if test="$baud=3">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				2400
			</option>
			<option value="4">
				<xsl:if test="$baud=4">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				4800
			</option>
			<option value="5">
				<xsl:if test="$baud=5">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				9600
			</option>
			<option value="6">
				<xsl:if test="$baud=6">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				14400
			</option>
			<option value="7">
				<xsl:if test="$baud=7">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				19200
			</option>
			<option value="8">
				<xsl:if test="$baud=8">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				38400
			</option>
			<option value="9">
				<xsl:if test="$baud=9">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				57600
			</option>
			<option value="10">
				<xsl:if test="$baud=10">
					<xsl:attribute name="selected">selected</xsl:attribute>
				</xsl:if>
				115200
			</option>
		</select>
		Bd
  </xsl:template>


  <xsl:template match="InverterSet" mode="Inverter">
		<script type="text/javascript" language="JavaScript">
			function setEmail()
			{
				var checked = document.getElementById("Email").checked;
				var box;
				for (var i = 0; (box = document.getElementById("InverterSet.Email."+i)) != null; i++)
				{
					box.checked = checked;
				}
				for (var i = 0; (box = document.getElementById("StringSet.Email."+i)) != null; i++)
				{
					box.checked = checked;
				}
			}
			function setSMS()
			{
				var checked = document.getElementById("SMS").checked;
				var box;
				for (var i = 0; (box = document.getElementById("InverterSet.SMS."+i)) != null; i++)
				{
					box.checked = checked;
				}
				for (var i = 0; (box = document.getElementById("StringSet.SMS."+i)) != null; i++)
				{
					box.checked = checked;
				}
			}
			function validateProtocol()
			{
				var protocol = document.getElementById("Protocol").value;

				var protocol2 = document.getElementById("Protocol2");
				var baudrate2 = document.getElementById("BaudRate2");
				
				switch (Number(protocol))
				{
					case 0:
					case 1:
					case 7:
					case 8:
					case 9:
						protocol2.disabled = 'disabled';
						baudrate2.disabled = 'disabled';
						break;
					default:
						protocol2.disabled = '';
						baudrate2.disabled = '';
						break; 
				}
			}
		</script>
    <h1><xsl:value-of select="$lg/s[94]"/></h1>
    <p>	
      <table class="tbl_half">
        <colgroup>
          <col class="col_name_middle"/>
          <col class="col_value"/>
          <col class="col_help"/>
        </colgroup>
        <tbody>
          <tr>
            <td>
            	<xsl:value-of select="$lg/s[95]"/> (A, B):
            </td>
            <td>                                                     	
							<xsl:call-template name="Protocol"><xsl:with-param name="prot" select="Protocol"/></xsl:call-template>
						</td>
            <td/>
          </tr>
          <tr>
						<td>
							<xsl:value-of select="$lg/s[96]"/>:
						</td>
            <td>
            	<xsl:call-template name="BaudRate"><xsl:with-param name="baud" select="BaudRate"/></xsl:call-template>
						</td>
						<td/>
          </tr>
          <tr>
            <td>
            	<xsl:value-of select="$lg/s[95]"/> (Y, Z):
            </td>
            <td>                                                     	
							<xsl:call-template name="Protocol"><xsl:with-param name="prot" select="Protocol2"/></xsl:call-template>
						</td>
            <td/>
          </tr>
          <tr>
						<td>
							<xsl:value-of select="$lg/s[96]"/>:
						</td>
            <td>
            	<xsl:call-template name="BaudRate"><xsl:with-param name="baud" select="BaudRate2"/></xsl:call-template>
						</td>
						<td/>
          </tr>
	      </tbody>
  		</table>
    </p>
  </xsl:template>

  <xsl:template match="InverterSet" mode="Inverter3">
    <h1><xsl:value-of select="$lg/s[328]"/></h1>
    <p>	
      <table class="tbl_half">
        <colgroup>
          <col class="col_name_middle"/>
          <col class="col_value"/>
          <col class="col_help"/>
        </colgroup>
        <tbody>
          <tr>
						<td><xsl:value-of select="$lg/s[97]"/>:</td>
						<td>
            	<input type="checkbox" class="checkbox" id="Warning">
    						<xsl:if test="Warning &gt; 0">
    							<xsl:attribute name="checked"><xsl:value-of select="checked"/></xsl:attribute>
    						</xsl:if>
    					</input>
            </td>
						<td/>
          </tr>
          <tr>
						<td><xsl:value-of select="$lg/s[301]"/>:</td>
						<td>
							<xsl:value-of select="count(Entry) + count(//StringSet/Entry)"/>
						</td>
						<td/>
          </tr>
	      </tbody>
  		</table>
    </p>
  </xsl:template>

  <xsl:template match="InverterSet" mode="Inverter2">
    <p>
			<table class="tbl_full">
			  <col class="col_value" width="7%"/>
			  <col class="col_value" nowrap="1"/>
			  <col class="col_value"/>
			  <col class="col_value"/>
			  <col class="col_value"/>
			  <col class="col_value"/>
			  <col class="col_value"/>
				<thead>
					<td>ID</td>
					<td><xsl:value-of select="$lg/s[99]"/> <span class="info">
						<xsl:attribute name="title"><xsl:value-of select="$lg/s[238]"/></xsl:attribute>
						?
					</span></td>
					<td>SN <span class="info">
						<xsl:attribute name="title"><xsl:value-of select="$lg/s[239]"/></xsl:attribute>
						?
					</span></td>
					<td><xsl:value-of select="$lg/s[72]"/> <span class="info">
						<xsl:attribute name="title"><xsl:value-of select="$lg/s[240]"/></xsl:attribute>
						?
					</span></td>
					<td><xsl:value-of select="$lg/s[98]"/> <span class="info">
						<xsl:attribute name="title"><xsl:value-of select="$lg/s[241]"/></xsl:attribute>
						?
					</span></td>
					<td>e-mail 
						<span class="info">
							<xsl:attribute name="title"><xsl:value-of select="$lg/s[242]"/></xsl:attribute>
							?
						</span>
						<input type="checkbox" id="Email" class="checkbox">
							<xsl:attribute name="onclick">
								setEmail();
							</xsl:attribute>
							<xsl:if test="//InverterSet/Entry[1]/Email != 0">
								<xsl:attribute name="checked"/>
							</xsl:if>
						</input>
					</td>
					<td>SMS
						<span class="info">
							<xsl:attribute name="title"><xsl:value-of select="$lg/s[243]"/></xsl:attribute>
							?
						</span>	
						<input type="checkbox" id="SMS" class="checkbox">
							<xsl:if test="not(//SMS/E!=0)">
								<xsl:attribute name="disabled">1</xsl:attribute>
							</xsl:if>
							<xsl:attribute name="onclick">
								setSMS();
							</xsl:attribute>
							<xsl:if test="//InverterSet/Entry[1]/SMS != 0">
								<xsl:attribute name="checked"/>
							</xsl:if>
						</input>
					</td>
				</thead>
				<tbody>
					<xsl:choose>
						<xsl:when test="GwMode=1">
							<tr>
								<td style="text-align:center;" colspan="7">
									<xsl:value-of select="$lg/s[300]"/>
								</td>
							</tr>
						</xsl:when>
						<xsl:when test="Detection=1">
							<script type="text/javascript" language="JavaScript">
								DetectionInProgress();
							</script>
							<tr>
								<td style="text-align:center;" colspan="7">
									<xsl:value-of select="$lg/s[100]"/>												
								</td>
							</tr>
						</xsl:when>
						<xsl:otherwise>      
							<xsl:for-each select="Entry">
								<xsl:apply-templates select="." mode="rs485_device"/>
							</xsl:for-each>
							<xsl:for-each select="//StringSet/Entry">
								<xsl:apply-templates select="." mode="rs485_device"/>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</tbody>
			</table>
    </p>
 		<p class="right">
			<input type="button" class="input_auto" style="margin-top: .2em" onClick="SetInvertersAndMeasurement(true);">
				<xsl:attribute name="value"><xsl:value-of select="$lg/s[207]"/></xsl:attribute>
			</input>
		</p>	
  </xsl:template>  

  <xsl:template match="Entry" mode="rs485_device">
		<xsl:variable name="idx">
			<xsl:variable name="entry" select="."/>
			<xsl:for-each select="../Entry">
				<xsl:if test="$entry = .">
					<xsl:value-of select="position() - 1"/>				
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<tr>
			<td style="text-align:center;">
				<xsl:value-of select="ID"/>
				<input type="hidden" class="input_text">
					<xsl:attribute name="id">
						<xsl:value-of select="name(..)"/>.ID.<xsl:number value="$idx"/>
					</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
				</input>
			</td>
			<td style="text-align:center;">
				<xsl:attribute name="id"><xsl:value-of select="name(..)"/>Type<xsl:number value="$idx"/></xsl:attribute>
				<xsl:value-of select="Type"/>
			</td>
			<td style="text-align:center;">
				<xsl:attribute name="id"><xsl:value-of select="name(..)"/>Sn<xsl:number value="$idx"/></xsl:attribute>
				<xsl:value-of select="SN"/>
			</td>
			<td style="text-align:center;">
				<xsl:attribute name="id"><xsl:value-of select="name(..)"/>On<xsl:number value="$idx"/></xsl:attribute>
				<xsl:choose>
				  <xsl:when test="Online=0">
						<xsl:value-of select="$lg/s[76]"/>
				  </xsl:when>
				  <xsl:when test="Online=1">
						<xsl:value-of select="Error"/>
						<xsl:if test="ErrorDetailed!=0"> 0x<xsl:value-of select="ErrorDetailed"/>
						</xsl:if>
				  </xsl:when>
				  <xsl:when test="Online=2">
						<xsl:value-of select="$lg/s[78]"/>
				  </xsl:when>
				</xsl:choose>
			</td>
			<td style="text-align:center;">
				<xsl:value-of select="$lg/s[93]"/> (Ok)
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox">
					<xsl:attribute name="id">
						<xsl:value-of select="name(..)"/>.Email.<xsl:number value="$idx"/>
					</xsl:attribute>
					<xsl:if test="Email &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox">
					<xsl:if test="not(//SMS/E!=0)">
						<xsl:attribute name="disabled">1</xsl:attribute>
					</xsl:if>
					<xsl:attribute name="id">
						<xsl:value-of select="name(..)"/>.SMS.<xsl:number value="$idx"/>
					</xsl:attribute>
					<xsl:if test="SMS &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
		</tr> 
	</xsl:template>  

	<xsl:template match="Electrometer">
		<h1><xsl:value-of select="$lg/s[158]"/></h1>
		<p>
      <table class="tbl_half">
        <colgroup>
          <col class="col_name_middle" style="width:14em;"/>
          <col class="col_value"/>
          <col class="col_help"/>
        </colgroup>                                                          
        <tbody>
          <tr>
            <td><xsl:value-of select="$lg/s[159]"/></td>
            <td>
              <input type="text" id="Pulses" onchange="PulsesModified();">
                <xsl:attribute name="value">
									<xsl:value-of select="Pulses"/>
									<xsl:if test="Ratio!=1">/<xsl:value-of select="Ratio"/></xsl:if>
								</xsl:attribute>
              </input>
            </td>
						<td>
							 <span class="info">
							 	<xsl:attribute name="title"><xsl:value-of select="$lg/s[271]"/></xsl:attribute>
							 	?
							 </span>
						</td>
          </tr>
         	<tr>
						<td><xsl:value-of select="$lg/s[160]"/> [kWp]</td>
						<td>
							<input type="text" maxlength="10" id="Power"><xsl:attribute name="value"><xsl:value-of select="Power div 10"/></xsl:attribute></input>
						</td>
						<td>
						  <span class="info">
						  	<xsl:attribute name="title"><xsl:value-of select="$lg/s[272]"/></xsl:attribute>
								?
							</span>
						</td>
					</tr>
          <tr>
            <td><xsl:value-of select="$lg/s[161]"/> [kWh]</td>
            <td>
              <input type="text" id="Total" onchange="EnergyModified();">
                <xsl:attribute name="value"><xsl:value-of select="//Energy/Total div 1000"/></xsl:attribute>
              </input>
            </td>
						<td>
							 <span class="info">
							 	<xsl:attribute name="title"><xsl:value-of select="$lg/s[273]"/></xsl:attribute>
							 	?
							 </span>
						</td>
          </tr>
          <tr>
            <td><xsl:value-of select="$lg/s[138]"/> [<xsl:value-of select="//Prices/Currency"/>/MWh]</td>
            <td>
              <input type="text" id="Main">
                <xsl:attribute name="value"><xsl:value-of select="//Prices/Main"/></xsl:attribute>
              </input>
            </td>
						<td>
							 <span class="info">
							 	<xsl:attribute name="title"><xsl:value-of select="$lg/s[274]"/></xsl:attribute>
							 	?
							 </span>
						</td>
          </tr>
          <tr>
            <td><xsl:value-of select="$lg/s[296]"/></td>
            <td>
              <input type="text" id="Currency" maxlength="3">
                <xsl:attribute name="value"><xsl:value-of select="//Prices/Currency"/></xsl:attribute>
              </input>
            </td>
						<td/>
          </tr>
	      </tbody>
      </table>
  	</p>
  </xsl:template>
</xsl:stylesheet>
