<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

  <xsl:template match="Invoice" mode="BoardCert">
		<xsl:choose>
			<xsl:when test="Producer=0">
  			Podnikatel zapsán v živnostenském rejstříku vedeném <xsl:value-of select="Board"/>, živnostenský list č.j. <xsl:value-of select="Certificate"/>.	
			</xsl:when>
			<xsl:otherwise>
				Firma vedena u soudu <xsl:value-of select="Board"/>, spisová značka <xsl:value-of select="Certificate"/>.
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  <xsl:template match="Identification/Entry">
		<table class="Tab1">
		  <tr class="EmptyRow"><td/></tr>
			<tr>
				<td class="TextHeading">
					<xsl:choose>
						<xsl:when test="Idx=1">
							DODAVATEL:
						</xsl:when>
						<xsl:otherwise>
							ODBĚRATEL:
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td class="bold">
					<xsl:value-of select="Name"/>, 
					<xsl:value-of select="Street"/>, 
					<xsl:if test="ZIP!=0"><xsl:value-of select="ZIP"/>, </xsl:if> 
					<xsl:value-of select="Town"/>						
				</td>
  	 	</tr>
	   	<tr class="EmptyRow"><td/></tr>
	  	<tr>
			 	<td>
					<table class="TabDetails">
						<colgroup>
							<col width="25%"/>
							<col width="25%"/>
							<col width="25%"/>
							<col width="25%"/>
						</colgroup>
						<tr>
							<td class="right">Telefon:</td><td><xsl:value-of select="Phone"/></td>
							<td class="right">Peněžní ústav:</td><td><xsl:value-of select="Bank"/></td>
						</tr>
						<tr>
							<td class="right">e-mail:</td><td><xsl:value-of select="Email"/></td>
							<td class="right">Číslo účtu:</td><td><xsl:value-of select="Account"/></td>
						</tr>
						<tr>
							<td class="right">IČ:</td><td><xsl:if test="IC!=0"><xsl:value-of select="IC"/></xsl:if></td>
							<xsl:if test="Idx=1">
								<td class="right">Variabilní symbol:</td>
								<td>
									<xsl:choose>
										<xsl:when test="//PrintInvoiceData/Entry[1]/Variable=''">
											0000000000
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="//PrintInvoiceData/Entry[1]/Variable"/>
										</xsl:otherwise>
									</xsl:choose>
								</td>
							</xsl:if>
						</tr>
						<tr>
							<td class="right"><xsl:if test="Idx!=1 or //Prices/TaxPayer=1">DIČ:</xsl:if></td><td><xsl:if test="Idx!=1 or //Prices/TaxPayer=1"><xsl:value-of select="DIC"/></xsl:if></td>
							<xsl:if test="Idx=1">
								<td class="right">ID RÚT:</td><td><xsl:if test="//Invoice/RUT!=0"><xsl:value-of select="//Invoice/RUT"/></xsl:if></td>
							</xsl:if>
						</tr>
					</table>
			  </td>
		  </tr>
		  <tr class="EmptyRow"><td/></tr>
			<tr>
				<td>
					<xsl:if test="Idx=1 and //Prices/TaxPayer=0">
						Dodavatel není platcem DPH.
					</xsl:if>
				</td>
			</tr>
		  <tr>
		  	<td>
					<xsl:if test="Idx=1">
						<xsl:apply-templates select="//Invoice" mode="BoardCert"/>
					</xsl:if>
				</td>
			</tr>
			<tr class="EmptyRow"><td/></tr>
		</table>
	</xsl:template>
	
<!--*************************************************************************-->
<!--*************************** INVOICE START *******************************-->
<!--*************************************************************************-->

  <xsl:template match="Root">
    <html>
      <head>
         <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <title>Faktura za výrobu z OZE</title>
        <link rel="stylesheet" type="text/css" href="index.css"/>
      </head>
      <body id="white_back">
				<xsl:if test="Print=1">
					<xsl:attribute name="onLoad">javascript:window.print();</xsl:attribute>
				</xsl:if>
				<div id="invoice">
          <table class="TabMain">
      	    <tr>
							<td>
							<tr>
								<td class="Text1">FAKTURA - DAŇOVÝ DOKLAD - OZE</td>
							</tr>      	    
							<tr>
					  		<td>
								  <table width="100%">
										<tr>
											<td class="Text2">Číslo objednávky (označení): <xsl:value-of select="Invoice/Markup"/></td>
											<td class="Text2" style="text-align:right">Číslo faktury: <xsl:value-of select="PrintInvoiceData/Entry[1]/Id"/></td>
											
										</tr>
									</table>
								</td>
	        		</tr>
  	    	    <tr><td><xsl:apply-templates select="Identification/Entry[1]"/></td></tr>
  	    	    <tr>
								<td>
									<xsl:choose>
										<xsl:when test="InvoiceType=0">
											<xsl:apply-templates select="Identification/Entry[2]"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:apply-templates select="Identification/Entry[3]"/>
										</xsl:otherwise>
									</xsl:choose>
	  	    	    </td>
							</tr>
							<tr>
								<td>
									<table class="Tab1">
										<tr class="EmptyRow">
											<td/>
										</tr>
										<tr>
										 	<td>
												<table class="TabDetails">
        									<colgroup>
													  <col width="50%"/>
													  <col width="50%"/>
        									</colgroup>
													<tr>
														<td>Datum vystavení:</td>
														<td><xsl:value-of select="Today"/></td>
													</tr>
													<tr>
														<td>Datum uskutečnění zdanitelného plnění:</td>
														<td>
															<xsl:value-of select="PrintInvoiceData/Entry[1]/To"/>
														</td>
													</tr>
													<tr>
														<td>Datum splatnosti:</td>
														<td><xsl:value-of select="MaturityDate"/></td>
													</tr>
													<tr>
														<td>Způsob úhrady:</td>
														<td>
						                  <xsl:if test="Invoice/Footage=0">
															  Převodem
						                  </xsl:if>
						                  <xsl:if test="Invoice/Footage=1">
														  	Přílazem k úhradě
						                  </xsl:if>
						                </td>
													</tr>
												</table>
											</td>
										</tr>
										<tr class="EmptyRow">
											<td/>
									  </tr>
									</table>
								</td>
							</tr>
							<tr>
							  <td>
						      <table class="Tab1">
									  <tr class="EmptyRow">
											<td/>
									  </tr>
									  <tr>
									  	<td>
												<table class="TabDetails">
        									<colgroup>
													  <col width="75%"/>
													  <col width="25%"/>
        									</colgroup>
													<tr>
														<td colspan="2">
															Na základě smlouvy
															<xsl:if test="InvoiceType=0">
																<xsl:if test="string-length(Invoice/NumberMain)>0">
																	č. <xsl:value-of select="Invoice/NumberMain"/> 
															 	</xsl:if>
															</xsl:if>
															<xsl:if test="InvoiceType=1">
																<xsl:if test="string-length(Invoice/NumberSell)>0">
																	č. <xsl:value-of select="Invoice/NumberSell"/> 
															 	</xsl:if>
															</xsl:if>
															o
															<xsl:if test="InvoiceType=0">
																podpoře výroby elektřiny
															</xsl:if>
															<xsl:if test="InvoiceType=1">
																dodávce elektřiny 
															</xsl:if>
															z obnovitelných zdrojů ze dne
															<xsl:if test="InvoiceType=0">
																<xsl:value-of select="Invoice/DateMain"/>
															</xsl:if>
															<xsl:if test="InvoiceType=1">
																<xsl:value-of select="Invoice/DateSell"/>
															</xsl:if>
															 a údajů zjištěných z elektroměru a vykázaných v Měsíčním výkaze o výrobě elektřiny z obnovitelných zdrojů, který je přílohou této faktury,</td>
													</tr>
													<tr class="EmptyRow">
														<td/>
														<td/>
													</tr>
													<tr>
														<td class="TextHeading">vám fakturujeme za dodanou/vykázanou elektřinu za období:</td>
														<td class="TextHeading">
															<xsl:value-of select="PrintInvoiceData/Entry[1]/From"/>
															 - 
															<xsl:value-of select="PrintInvoiceData/Entry[1]/To"/>
														</td>
													</tr>
													<tr class="EmptyRow">
														<td/>
														<td/>
													</tr>
												</table>
											</td>
									  </tr>
									</table>
								</td>
							</tr>			
							<tr>
							  <td>
						      <table class="Tab2">
							    <tr>
									<td>
										<!--<colgroup>
												  <col width="33%"/>
												  <col width="33%"/>
												  <col width="33%"/>
										</colgroup>-->
										<tr>
											<td colspan="3">EAN (18): <xsl:value-of select="Invoice/EAN"/></td>
										</tr>
										<tr>
											<td colspan="3">Číslo elektroměru:<xsl:value-of select="Invoice/Electrometer"/></td>
										</tr>
										<tr class="EmptyRow"></tr>
										<tr>
											<td>Položka:</td>
											<td>Počáteční stav [MWh]</td>
											<td>Konečný stav [MWh]</td>
											<td class="bold">Vyrobená elektřina [MWh]</td>
											<td>Jednotková cena [Kč/MWh]</td>
											<xsl:if test="Prices/TaxPayer=1">
												<td>Základ daně [Kč]</td>
												<td>DPH [Kč]</td>
											</xsl:if>
											<td class="bold">Celkem Kč:</td>
										</tr>	
										<tr>
											<td class="Underline"/>
											<td class="Underline">(<xsl:value-of select="PrintInvoiceData/Entry[1]/From"/>)</td>
											<td class="Underline">(<xsl:value-of select="PrintInvoiceData/Entry[1]/To"/>)</td>
											<td class="Underline"/>
											<td class="Underline"/>
											<xsl:if test="Prices/TaxPayer=1">
												<td class="Underline"/>
												<td class="Underline">(<xsl:value-of select="Prices/VAT"/>%)</td>
											</xsl:if>
											<td class="Underline"><xsl:if test="Prices/TaxPayer=1"> (včetně DPH)</xsl:if></td>
										</tr>	
													
										<xsl:choose>
											<!-- Výroba a decentrální výroba -->
											<xsl:when test="InvoiceType=0">
												<tr>
													<td>
														<xsl:if test="Prices/Mode=0">
															Zelený bonus
														</xsl:if>
														<xsl:if test="Prices/Mode=1">
															Povinný výkup
														</xsl:if>
													</td>
													<xsl:apply-templates select="Prices/Main" mode="All"/>
												</tr>
												<tr>
													<xsl:if test="12 > substring-after(//PrintInvoiceData/Entry[Idx=1]/To, '.20')">
														<td>Decentrální výroba</td>
														<!-- Zeleny bonus-->
														<xsl:if test="Prices/Mode=0">
															<xsl:apply-templates select="Prices/Decentral" mode="Sell"/>
														</xsl:if>
														<!-- Povinny vykup-->
														<xsl:if test="Prices/Mode=1">
															<xsl:apply-templates select="Prices/Decentral" mode="All"/>
														</xsl:if>
													</xsl:if>
												</tr>
											</xsl:when>
											<!-- Prodej -->
											<xsl:otherwise>
												<td>Dodaná elektřina</td>
												<xsl:apply-templates select="Prices/Sell" mode="Sell"/>
											</xsl:otherwise>
										</xsl:choose>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>
							<table class="Tab1">
							  <tr class="EmptyRow">
									<td/>
							  </tr>
							  <tr>
								<td>
									<table class="TabDetails">
									<colgroup>
											  <col width="75%"/>
											  <col width="25%"/>
									</colgroup>
									<xsl:variable name="value">
											<xsl:choose>
													<!-- Tisk faktury za výrobu a decentrální výrobu -->
													<xsl:when test="InvoiceType=0">
														<xsl:choose>
															<!-- Zelený bonus -->
															<xsl:when test="Prices/Mode=0">
																<xsl:value-of select="(Prices/Main * Production/Total div 1000) + (Prices/Decentral * PrintInvoiceData/Entry[1]/Total div 1000)"/>
															</xsl:when>
															<!-- Povinný výkup -->
															<xsl:otherwise>
																<xsl:value-of select="(Prices/Main + Prices/Decentral) * Production/Total div 1000"/>
															</xsl:otherwise>
														</xsl:choose>
													</xsl:when>
													<!-- Tisk faktury za prodej -->
													<xsl:otherwise>
														<xsl:value-of select="Prices/Sell * PrintInvoiceData/Entry[1]/Total div 1000"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>
											<tr>
												<td class="bold">Celkem<xsl:if test="Prices/TaxPayer=1"> (bez DPH)</xsl:if>:</td>
												<td class="bold"><xsl:value-of select="floor($value * 100) div 100"/> Kč</td>
											</tr>
											<xsl:if test="Prices/TaxPayer=1">
												<tr>
													<td class="bold">Celkem DPH:</td>
													<td class="bold"><xsl:value-of select="floor($value * Prices/VAT) div 100"/> Kč</td>
												</tr>
												<tr>
													<td class="bold">Celkem k úhradě (včetně DPH):</td>
													<td class="bold"><xsl:value-of select="floor($value * (100 + Prices/VAT)) div 100"/> Kč</td>
												</tr>
											</xsl:if>
										</table>
									</td>
							  </tr>
							  <tr class="EmptyRow">
									<td/>
							  </tr>
							</table>
								</td>
							</tr>			
							<tr>
							  <td>
									<table class="Tab1">
										<tr class="EmptyRow">
											<td/>
										</tr>
										<tr>
											<td class="TextHeading">Vystavil:</td>
										</tr>
										<tr>
											<td><xsl:value-of select="Invoice/Issuer"/>, tel.: <xsl:value-of select="Invoice/Phone"/></td>
										</tr>
										<tr class="EmptyRow">
											<td/>
										</tr>
										<tr>
											<td>Podpis:</td>
										</tr>
										<tr class="HighEmptyRow">
											<td/>
										</tr>
										<tr class="EmptyRow">
<!--											<img src="logo.png" width="20%" align="right"/>	-->
											<td/>
										</tr>
										</table>
									</td>
								</tr>			
							</td>
						</tr>
				  </table>
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="Total">
		<td><xsl:value-of select="../Start div 1000"/></td>
		<td><xsl:value-of select="../End div 1000"/></td>
	</xsl:template>

  <xsl:template match="Prices/*" mode="Sell">
  	<xsl:variable name="value" select="//PrintInvoiceData/Entry[1]/Total"/>
  	<xsl:apply-templates select="$value"/>
		<td class="bold"><xsl:value-of select="$value div 1000"/></td>
		<td><xsl:value-of select="."/></td>
		<xsl:if test="//Prices/TaxPayer=1">
			<td><xsl:value-of select="floor(. * $value * 100 div 1000) div 100"/></td>
			<td class="bold"><xsl:value-of select="floor(. * $value * ../VAT div 1000) div 100"/></td>
		</xsl:if>			
		<td class="bold"><xsl:value-of select="floor(. * $value * ((../VAT * //Prices/TaxPayer) + 100) div 1000) div 100"/></td>
  </xsl:template>

  <xsl:template match="Prices/*" mode="All">
  	<xsl:variable name="value" select="//Production/Total" />
  	<xsl:apply-templates select="$value"/>
		<td class="bold"><xsl:value-of select="$value div 1000"/></td>
		<td><xsl:value-of select="."/></td>
		<xsl:if test="//Prices/TaxPayer=1">
			<td><xsl:value-of select="floor(. * $value * 100 div 1000) div 100"/></td>
			<td class="bold"><xsl:value-of select="floor(. * $value * ../VAT div 1000) div 100"/></td>
		</xsl:if>
<!-- TaxPayer musi byt 1 nebo 0 !!!!! Jinak nezafunguje!!!!!! - zkusit osetrit !!!! -->
		<td class="bold"><xsl:value-of select="floor(. * $value * ((../VAT * //Prices/TaxPayer) + 100) div 1000) div 100"/></td>
		<tr class="EmptyRow"/>
  </xsl:template>

</xsl:stylesheet>
