<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ovr="http://www.etech.cz/XMLSchema/sim/overall.xsd">

	<xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

	<xsl:include href="template.xsl"/>

	<xsl:template match="ovr:Root">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="index.css" />
				<script type="text/javascript" src="setup.js"></script>
				<title><xsl:call-template name="title"/></title>
			</head>
			<body onLoad="setInvPeakDisplay();">
				<div id="container">
					<div id="min_height"></div>
					<div id="sidebar">
						<div id="sidebar-content">
							<div id="logo">
								<div id="logo_trans"/>
							</div>
							<div id="menu">
								<xsl:apply-templates select="Agent/Menu"/>
							</div>
							<div id="submit_area">
								<input type="button" class="input_auto" onClick="setOverall();">
									<xsl:attribute name="value"><xsl:value-of select="$lg/s[289]"/></xsl:attribute>
								</input>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
					<div id="main-div">
						<div id="main-content">
							<div id="top_area">
							  <div id="dev_name"><xsl:value-of select="Agent/DeviceName"/></div>
							  <div id="caption"><xsl:value-of select="$lg/s[7]"/></div>
							</div>
							<div id="content">
								<div class="column_left">
									<xsl:apply-templates select="Energy" mode="Overall"/>
									<xsl:if test="InverterSet/Entry">
										<xsl:apply-templates select="PeakSettings"/>
								</xsl:if>
								</div>
								<div class="column_right">
									<h1><xsl:value-of select="$lg/s[211]"/></h1>
									<p>
										<table class="tbl_half">
											<colgroup> 
												<col class="col_name_middle"/>
												<col class="col_value"/>
												<col class="col_help"/>
												<col class="col_help"/>
											</colgroup>
											<tbody>
												<xsl:apply-templates select="Effectivity"/>
												<xsl:apply-templates select="RunTimeSet"/>							
											</tbody>
										</table>
									</p>	
								</div>
								<div class="column_full">
										<xsl:apply-templates select="PeakSet"/>
								</div>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
				</div>          
				<div id="bottom-contact">
					<xsl:apply-templates select="Agent/Contact"/>
				</div>
			</body>
		</html>
	</xsl:template>

	<!-- TEMPLATE -->

  <xsl:template match="InverterSet/Entry" mode="Peaks">
		<xsl:value-of select="Type"/>
		<xsl:if test="SN != '-'">
			SN: <xsl:value-of select="SN"/>
		</xsl:if>
		<xsl:if test="SN = '-'">
			ID: <xsl:value-of select="ID"/>
		</xsl:if>
	</xsl:template>
		
  <xsl:template match="InverterSet" mode="Peaks">
		 <xsl:value-of select="$lg/s[183]"/>: 
		<select id="inv_idx" style="margin-left:15px" onChange="setInvPeakDisplay();">
			<option value="0">
				-
			</option>
			<xsl:for-each select="//PeakSettings/Entry[ID != 0]">
				<xsl:variable name="ID">
					<xsl:value-of select="ID"/>
				</xsl:variable>	
				<xsl:variable name="pos">
					<xsl:value-of select="position()"/>
				</xsl:variable>	
				<xsl:for-each select="//InverterSet/Entry[$ID = ID]">
					<option>
						<xsl:attribute name="value"><xsl:value-of select="$pos"/></xsl:attribute>
						<xsl:if test="$pos = 1">
							<xsl:attribute name="selected">1</xsl:attribute>
						</xsl:if>
					<xsl:apply-templates select="." mode="Peaks"/>
					</option>
				</xsl:for-each>
			</xsl:for-each>
		</select>
	</xsl:template>

	<xsl:template match="PeakSettings">
		<h1><xsl:value-of select="$lg/s[184]"/></h1>
		<p>
      <table class="tbl_half">
        <colgroup>
          <col class="col_name_middle"/>
          <col class="col_value"/>
        </colgroup>
        <tbody>
		   		<xsl:variable name="inv_cnt">
						 <xsl:value-of select="count(//InverterSet/Entry)"/>
					</xsl:variable>
					<xsl:for-each select="Entry">
						<xsl:if test="$inv_cnt >= position()">
							<input type="hidden">
								<xsl:attribute name="id">
									<xsl:value-of select="name(..)"/>.Idx.<xsl:number value="position()-1"/>
								</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="Idx"/></xsl:attribute>
							</input>
							<tr>
								<td><xsl:value-of select="$lg/s[185]"/>&#160;<xsl:value-of select="Idx"/></td>
								<td>
									<select>
										<xsl:attribute name="ID">
											<xsl:value-of select="name(..)"/>.ID.<xsl:number value="position()-1"/>
										</xsl:attribute>
										
							   		<xsl:variable name="ID">
											<xsl:value-of select="ID"/>
										</xsl:variable>	
																		
										<option value="0">
											<xsl:if test="ID = 0">
												<xsl:attribute name="selected">selected</xsl:attribute>                                                                                                                                                                                                             
											</xsl:if>
											-
										</option>
										<xsl:for-each select="//InverterSet/Entry">
											<option>
												<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
												<xsl:if test="ID = $ID">
													<xsl:attribute name="selected">selected</xsl:attribute>
												</xsl:if>
												<xsl:value-of select="Type"/>
												<xsl:if test="SN != '-'">
													SN: <xsl:value-of select="SN"/>
												</xsl:if>
												<xsl:if test="SN = '-'">
													ID: <xsl:value-of select="ID"/>
												</xsl:if>
											</option>
										</xsl:for-each>
									</select>
								</td>
							</tr>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</p>
	</xsl:template>

	<xsl:template match="PeakSet">
		<script type="text/javascript" language="JavaScript">
			function setAll(offs, cnt)
			{
				var checked = document.getElementById("All").checked;
				var idx = document.getElementById("inv_idx").value;
				var box;
				for (var i = 0; (box = document.getElementById("PeakSet.Erase."+i)) != null; i++)
				{
					box.checked = 0;
					if (offs>i)
					{
						box.checked = checked;
					}
					else if (Number(idx))
					{
						if (!((i-(Number(offs)+Number(idx))+1)%cnt))
							box.checked = checked;
					}
				}
			}
			function setInvPeakDisplay()
			{
				var visible = document.getElementById("inv_idx").value - 1;
				for (var i = 0; document.getElementById("PeakSet.Fac."+i) != null; i++)
				{
					var fac = document.getElementById("PeakSet.Fac."+i).style;
					var uac = document.getElementById("PeakSet.Uac."+i).style
					var iac = document.getElementById("PeakSet.Iac."+i).style
					var pac = document.getElementById("PeakSet.Pac."+i).style;
					var upv = document.getElementById("PeakSet.Upv."+i).style;
					var ipv = document.getElementById("PeakSet.Ipv."+i).style;
					var tkk = document.getElementById("PeakSet.Tkk."+i).style;
					
					if (i == visible)
					{
						fac.display =
						uac.display =
						iac.display =
						pac.display =
						upv.display =
						ipv.display =
						tkk.display = 'block';
					}
					else
					{
						fac.display =
						uac.display =
						iac.display =
						pac.display =
						upv.display =
						ipv.display =
						tkk.display = 'none';
					}
				}
			}
		</script>
		<h1><xsl:value-of select="$lg/s[186]"/>&#160;<xsl:apply-templates select="//InverterSet" mode="Peaks"/></h1>
		<p>
			<!-- Promenna pro max. pocet stridacu -->
			<xsl:variable name="cnt">
				<xsl:value-of select="MaxCnt"/>
			</xsl:variable>
			<xsl:variable name="offs">
				<xsl:for-each select="//SenSet/Entry">
					<xsl:if test="position()=last()">
						<xsl:value-of select="last()"/>
					</xsl:if>
				</xsl:for-each>
				<xsl:if test="not(//SenSet/Entry)">
					0
				</xsl:if>
			</xsl:variable>
			<table class="tbl_full" style="border-bottom:0;">
				<colgroup> 
					<col class="col_name_wide" width="33%"/>
					<col class="col_value" width="8%"/>
					<col class="col_value" width="23%"/>
					<col class="col_value" width="8%"/>
					<col class="col_value" width="23%"/>
					<col class="col_value" width="15px"/>
				</colgroup>
				<thead>
					<tr>
						<td><xsl:value-of select="$lg/s[85]"/></td>
						<td><xsl:value-of select="$lg/s[187]"/></td>
						<td><xsl:value-of select="$lg/s[188]"/></td>
						<td><xsl:value-of select="$lg/s[189]"/></td>
						<td><xsl:value-of select="$lg/s[188]"/></td>
						<td><xsl:value-of select="$lg/s[190]"/><input type="checkbox" id="All" class="checkbox">
								<xsl:attribute name="onclick">
									setAll(<xsl:value-of select="$offs"/>,<xsl:value-of select="$cnt"/>);
								</xsl:attribute>
							</input>	
						</td>
					</tr>
				</thead>
			</table>
			<xsl:for-each select="Entry">
				<div>
					<xsl:variable name="pos" select="position()"/>
					<xsl:variable name="one" select="$pos>($offs)"/>
					<xsl:variable name="two" select="$pos>($offs+1*$cnt)"/>
					<xsl:variable name="three" select="$pos>($offs+2*$cnt)"/>
					<xsl:variable name="four" select="$pos>($offs+3*$cnt)"/>
					<xsl:variable name="five" select="$pos>($offs+4*$cnt)"/>
					<xsl:variable name="six" select="$pos>($offs+5*$cnt)"/>
					<xsl:variable name="seven" select="$pos>($offs+6*$cnt)"/>
					<xsl:variable name="dec">
						<xsl:choose>
							<xsl:when test="$seven">100</xsl:when>
							<xsl:when test="$six">1</xsl:when>
							<xsl:when test="$five">1</xsl:when>
							<xsl:when test="$four">10</xsl:when>
							<xsl:when test="$three">1</xsl:when>
							<xsl:when test="$two">1</xsl:when>
							<xsl:when test="$one">1</xsl:when>
							<xsl:otherwise>10</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="idx">
						<xsl:value-of select="(($pos)-($offs)-1)mod($cnt)"/>
					</xsl:variable>
					<xsl:variable name="temp_idx">
						<xsl:for-each select="//InverterSet/Entry">
							<xsl:if test="ID = //PeakSettings/Entry[$idx + 1]/ID">
								<xsl:value-of select="position()"/>
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>
					<xsl:attribute name="id">
						<xsl:choose>
							<xsl:when test="$seven"><xsl:value-of select="name(..)"/>.Fac.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$six"><xsl:value-of select="name(..)"/>.Uac.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$five"><xsl:value-of select="name(..)"/>.Iac.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$four"><xsl:value-of select="name(..)"/>.Tkk.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$three"><xsl:value-of select="name(..)"/>.Pac.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$two"><xsl:value-of select="name(..)"/>.Upv.<xsl:number value="($idx)"/></xsl:when>
							<xsl:when test="$one"><xsl:value-of select="name(..)"/>.Ipv.<xsl:number value="($idx)"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="name(..)"/>.Sen.<xsl:number value="($idx)"/></xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="style">
						<xsl:choose>
							<xsl:when test="$seven">display:none</xsl:when>
							<xsl:when test="$six">display:none</xsl:when>
							<xsl:when test="$five">display:none</xsl:when>
							<xsl:when test="$four">display:none</xsl:when>
							<xsl:when test="$three">display:none</xsl:when>
							<xsl:when test="$two">display:none</xsl:when>
							<xsl:when test="$one">display:none</xsl:when>
						</xsl:choose>
					</xsl:attribute>
					<table class="tbl_full" style="border:0;">
						<colgroup> 	
							<col class="col_name_wide" width="33%"/>
							<col class="col_value" width="8%"/>
							<col class="col_value" width="23%"/>
							<col class="col_value" width="8%"/>
							<col class="col_value" width="23%"/>
							<col class="col_value" width="5%"/>
						</colgroup>
						<tbody>
							<tr>
								<input type="hidden">
									<xsl:attribute name="id">
										<xsl:value-of select="name(..)"/>.Idx.<xsl:value-of select="position()-1"/>
									</xsl:attribute>
									<xsl:attribute name="value"><xsl:value-of select="Idx"/></xsl:attribute>
								</input>
								<td>
									<xsl:choose>
										<xsl:when test="$seven">
											Fac 1 - <xsl:value-of select="$lg/s[191]"/>
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Fac 1'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Fac 1'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Fac 1']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											Hz]
										</xsl:when>
										<xsl:when test="$six">
											Uac 1 - <xsl:value-of select="$lg/s[192]"/>
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Uac 1'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Uac 1'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Uac 1']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											V]
										</xsl:when>
										<xsl:when test="$five">
											Iac 1 - <xsl:value-of select="$lg/s[193]"/> 
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Iac 1'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Iac 1'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Iac 1']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											mA]
										</xsl:when>
										<xsl:when test="$four">
											Tkk - <xsl:value-of select="$lg/s[194]"/> 
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Tkk'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Tkk'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Tkk']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											°C]
										</xsl:when>
										<xsl:when test="$three">
											Pac - <xsl:value-of select="$lg/s[195]"/> 
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Pac'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Pac'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Pac']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											W]
										</xsl:when>
										<xsl:when test="$two">
											Upv 1 - <xsl:value-of select="$lg/s[196]"/>
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Upv 1'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Upv 1'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Upv 1']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											V]
										</xsl:when>
										<xsl:when test="$one">
											Ipv 1  - <xsl:value-of select="$lg/s[197]"/>
											[<xsl:choose>
												<xsl:when test="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Ipv 1'] != '-'">
													<xsl:value-of select="//InverterSet/Entry[$temp_idx + 0]/Val[@n='Ipv 1'] div //InverterSet/Entry[$temp_idx + 0]/Val[@n='Ipv 1']/@m"/>
												</xsl:when>
												<xsl:otherwise>-</xsl:otherwise>
											</xsl:choose>
											mA]
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="//SenSet/Entry[$pos]/Name"/>
											[<xsl:apply-templates select="//SenSet/Entry[$pos]/Value"/><xsl:text> </xsl:text><xsl:apply-templates select="//SenSet/Entry[$pos]/Units"/>]
										</xsl:otherwise>
									</xsl:choose>
								</td>
								<xsl:choose>
									<xsl:when test="Min/Date='01.01.1970'">
										<td class="center">-</td><td class="center">-</td><td class="center">-</td><td class="center">-</td>
									</xsl:when>
									<xsl:otherwise>
										<td class="center"><xsl:value-of select="Min/Value div $dec"/></td>
										<td class="center">
											<xsl:value-of select="Min/Time"/>, 
											<xsl:value-of select="Min/Date"/>
										</td>
										<td class="center"><xsl:value-of select="Max/Value div $dec"/></td>
										<td class="center">
											<xsl:value-of select="Max/Time"/>, 
											<xsl:value-of select="Max/Date"/>
										</td>
									</xsl:otherwise>
								</xsl:choose>
								<td class="center">
									<input type="checkbox" class="checkbox" style="margin-left:-3px">
										<xsl:attribute name="id">
											<xsl:value-of select="name(..)"/>.Erase.<xsl:number value="position()-1"/>
										</xsl:attribute>
									</input>
								</td>
							</tr>
						</tbody>
					</table>
				</div>
			</xsl:for-each>
			<table class="tbl_full" style="border-bottom:0"><tr><td/></tr></table>
		</p>
		<p class="right">
			<input type="button" class="input_auto" onClick="resetOverall()">
				<xsl:attribute name="value"><xsl:value-of select="$lg/s[297]"/></xsl:attribute>
			</input>
		</p>
	</xsl:template>
	
	  <xsl:template match="Energy" mode="Overall">
    <h1><xsl:value-of select="$lg/s[163]"/></h1>
    <p>
      <table class="tbl_half">
        <colgroup>
          <col class="col_name_middle"/>
          <col class="col_value"/>
          <col class="col_help"/>
        </colgroup>
        <tbody>
          <tr>
            <td><xsl:value-of select="$lg/s[164]"/>:</td>
            <td><xsl:value-of select="floor(Total div(10))div(100)"/> kWh</td>
						<td><span class="info">
							<xsl:attribute name="title"><xsl:value-of select="$lg/s[275]"/></xsl:attribute>
							?
						</span></td>
          </tr>
          <tr>
            <td><xsl:value-of select="$lg/s[165]"/>:</td>
            <td><xsl:value-of select="floor((Total*../Prices/Main)div(10000))div(100)"/>&#160;<xsl:value-of select="//Prices/Currency"/></td>
						<td><span class="info">
							<xsl:attribute name="title"><xsl:value-of select="$lg/s[276]"/></xsl:attribute>	
							?
						</span></td>
          </tr>
          <tr>
            <td><xsl:value-of select="$lg/s[166]"/>:</td>
            <td><xsl:value-of select="floor((Total*0.537)div 10)div(100)"/> Kg</td>
						<td><span class="info">
							<xsl:attribute name="title"><xsl:value-of select="$lg/s[277]"/></xsl:attribute>
							?
						</span></td>
          </tr>
        </tbody>
      </table>
    </p>	
  </xsl:template>

	<xsl:template match="Effectivity">
    <tr>
    	<td><xsl:value-of select="$lg/s[167]"/>:</td>
    	<td><xsl:value-of select="Time"/>:00 - <xsl:value-of select="(Time + 1)mod(24)"/>:00</td>
			<td><input type="checkbox" id="EffClr" class="checkbox"/></td>
			<td><span class="info">
				<xsl:attribute name="title"><xsl:value-of select="$lg/s[278]"/></xsl:attribute>
				?
			</span></td>
		</tr>
	</xsl:template>
	
	<xsl:template match="RunTimeSet">
		<xsl:variable name="cnt">
			 <xsl:value-of select="count(//InverterSet/Entry)"/>
		</xsl:variable>
		<xsl:for-each select="Entry">
			<xsl:if test="($cnt)>=position()">
				<tr>
			    <td><xsl:value-of select="$lg/s[168]"/>&#160;<xsl:value-of select="position()"/>:</td>
			    <td>
			      <xsl:choose> 
						<xsl:when test="Date='01.01.1970'">
							-
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="floor(Time div(60*60))"/> hod (<xsl:value-of select="substring-before(Date,'.20')"/>.<xsl:value-of select="substring-after(Date,'.20')"/>)
						</xsl:otherwise>
			      </xsl:choose> 
					</td>
					<td>
						<input type="checkbox" class="checkbox">
							<xsl:attribute name="id">
								<xsl:value-of select="name(..)"/>.Erase.<xsl:number value="position()-1"/>
							</xsl:attribute>
						</input>
					</td>
					<td><span class="info">
						<xsl:attribute name="title"><xsl:value-of select="$lg/s[279]"/></xsl:attribute>
						?
					</span></td>
			  </tr>
				<input type="hidden">
					<xsl:attribute name="id">
						<xsl:value-of select="name(..)"/>.Idx.<xsl:value-of select="position()-1"/>
					</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Idx"/></xsl:attribute>
				</input>
			</xsl:if>
	  </xsl:for-each>
	</xsl:template>
</xsl:stylesheet>