<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:set="http://www.etech.cz/XMLSchema/sim/setup.xsd">

	<xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

	<xsl:include href="template.xsl"/>

	<xsl:template match="set:Root">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="index.css" />
				<script type="text/javascript" src="setup.js"></script>
				<title><xsl:call-template name="title"/></title>
			</head>
			<body>
			<div id="container">
					<div id="min_height"></div>
					<div id="sidebar">
						<div id="sidebar-content">
							<div id="logo">
								<div id="logo_trans"/>
							</div>
							<div id="menu">
								<xsl:apply-templates select="Agent/Menu"/>
							</div>
							<div id="submit_area">
								<input type="button" class="input_auto" onClick="setSensors();">
									<xsl:attribute name="value"><xsl:value-of select="$lg/s[289]"/></xsl:attribute>
								</input>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
					<div id="main-div">
						<div id="main-content">
							<div id="top_area">
							  <div id="dev_name"><xsl:value-of select="Agent/DeviceName"/></div>
							  <div id="caption"><xsl:value-of select="$lg/s[212]"/></div>
						    </div>
							<div id="content">
								<div class="column_left">
								  <h1><xsl:value-of select="$lg/s[213]"/></h1>
							    <p>
										<table class="tbl_full">
											<colgroup> 
											  <col class="col_value" width="8%"/>
											  <col class="col_value" width="37%"/>
											  <col class="col_value" width="17%"/>
											  <col class="col_value" width="22%"/>
											  <col class="col_value" width="8%"/>
											  <col class="col_value" width="8%"/>
											</colgroup> 
											<thead>
												<td>ID</td>
												<td><xsl:value-of select="$lg/s[57]"/>&#160;<span class="info">
													<xsl:attribute name="title"><xsl:value-of select="$lg/s[283]"/></xsl:attribute>
													?
												</span></td>
												<td><xsl:value-of select="$lg/s[72]"/>&#160;<span class="info">
													<xsl:attribute name="title"><xsl:value-of select="$lg/s[240]"/></xsl:attribute>
													?
												</span></td>
												<td><xsl:value-of select="$lg/s[98]"/>&#160;<span class="info">
													<xsl:attribute name="title"><xsl:value-of select="$lg/s[241]"/></xsl:attribute>
													?
												</span></td>
												<td>E-mail <span class="info" title="Poslat při překročení e-mail?">
													<xsl:attribute name="title"><xsl:value-of select="$lg/s[242]"/></xsl:attribute>
													?
												</span></td>
												<td>SMS <span class="info" title="Poslat při překročení SMS?">
													<xsl:attribute name="title"><xsl:value-of select="$lg/s[243]"/></xsl:attribute>
													?
												</span></td>
											</thead>
											<tbody>
												<xsl:apply-templates select="SenSet" mode="Sensors"/>
												<xsl:apply-templates select="InsolationAlarm" mode="Sensors"/>
												<xsl:apply-templates select="PeriodicalInfo" mode="Sensors"/>
												<xsl:apply-templates select="CommMonSet" mode="Sensors"/>
											</tbody>
										</table>
									</p>
									<p class="right">
										<xsl:if test="//Agent/Model!=4">
											<input type="button" class="input_auto" style="margin-top: .2em" onClick="return DetectSensors();">
												<xsl:attribute name="value"><xsl:value-of select="$lg/s[216]"/></xsl:attribute>
											</input>
										</xsl:if>
									</p>
								</div>
								<div class="column_left">
									<h1><xsl:value-of select="$lg/s[214]"/></h1>
									<p>
										<table class="tbl_half">
											<colgroup>
												<col class="col_name_wide"/>
												<col class="col_value"/>
												<col class="col_help"/>
											</colgroup>
											<tbody>
												<xsl:apply-templates select="DataLogger/Alarm"/>
												<xsl:apply-templates select="SoapReport/Alarm"/>
											</tbody>
										</table>
									</p>
								</div>
								<div class="column_right">
									<h1><xsl:value-of select="$lg/s[215]"/></h1>
									<p>
										<table class="tbl_half">
											<colgroup>
												<col class="col_name_wide"/>
												<col class="col_value"/>
												<col class="col_help"/>
											</colgroup>
											<tbody>
												<xsl:apply-templates select="SenSet/Delay"/>
												<xsl:apply-templates select="InverterSet/Delay"/>
												<xsl:apply-templates select="InsolationAlarm/Delay"/>
											</tbody>
										</table>
									</p>
								</div>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
				</div>          
				<div id="bottom-contact">
					<xsl:apply-templates select="Agent/Contact"/>
				</div>
			</body>
		</html>
	</xsl:template>

  <!-- TEMPLATE -->

	<xsl:template match="CommMonSet" mode="Sensors">
		<xsl:variable name="inv_cnt">
			 <xsl:value-of select="count(//InverterSet/Entry)"/>
		</xsl:variable>
		<xsl:variable name="str_cnt">
			 <xsl:value-of select="count(//StringSet/Entry)"/>
		</xsl:variable>
		<xsl:variable name="modbus_idx" select="0"/>
		<xsl:variable name="pulses_idx" select="1"/>
		<xsl:variable name="inv_idx" select="2"/>
		<xsl:for-each select="Entry"> 
			<xsl:choose> 
				<xsl:when test="(position() >= $inv_idx + $inv_cnt + $str_cnt)"/>
				<xsl:otherwise>
					<tr>
						<td style="text-align:center;">
							<input type="hidden">
								<xsl:attribute name="id">
									<xsl:value-of select="name(..)"/>.ID.<xsl:number value="position()-1"/>
								</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
							</input>
							<xsl:value-of select="ID"/>
						</td>
						<td class="left">
							<xsl:choose>
								<xsl:when test="position() = $pulses_idx">
									<xsl:value-of select="$lg/s[47]"/>
								</xsl:when>
								<xsl:when test="(position() >= $inv_idx) and (($inv_idx + $inv_cnt) > position())">
									<xsl:value-of select="$lg/s[48]"/>&#160;<xsl:value-of select="position() - $inv_idx + 1"/>
								</xsl:when>
								<xsl:when test="(position() >= $inv_idx + $inv_cnt) and (($inv_idx + $inv_cnt + $str_cnt) > position())">
									<xsl:value-of select="$lg/s[49]"/>&#160;<xsl:value-of select="position() - $inv_idx - $inv_cnt + 1"/>
								</xsl:when>
							</xsl:choose>
						</td>
						<td style="text-align:center;">
							<div>
							  <xsl:apply-templates select="State" mode="MonSenInvInp"/>
								<xsl:value-of select="Value"/>&#160;<xsl:value-of select="$lg/s[50]"/>
							</div>
						</td>
						<td style="text-align:center;">
							<input type="text" class="input_text_2" style="text-align:right;" id="">
								<xsl:attribute name="id">
									<xsl:value-of select="name(..)"/>.Timeout.<xsl:number value="position()-1"/>
								</xsl:attribute>
								<xsl:attribute name="value"><xsl:value-of select="Timeout"/></xsl:attribute>
							</input>&#160;<xsl:value-of select="$lg/s[50]"/>
							<span class="info">
								<xsl:attribute name="title"><xsl:value-of select="$lg/s[231]"/></xsl:attribute>
								?
							</span>
						</td>
						<td style="text-align:center;">
							<input type="checkbox"  class="checkbox">
								<xsl:attribute name="id">
									<xsl:value-of select="name(..)"/>.Email.<xsl:number value="position()-1"/>
								</xsl:attribute>
								<xsl:if test="Email &gt; 0">
									<xsl:attribute name="checked">checked</xsl:attribute>
								</xsl:if>
							</input>
						</td>
						<td style="text-align:center;">
							<input type="checkbox" class="checkbox">
								<xsl:if test="not(//SMS/E!=0)">
									<xsl:attribute name="disabled">1</xsl:attribute>
								</xsl:if>
								<xsl:attribute name="id">
									<xsl:value-of select="name(..)"/>.SMS.<xsl:number value="position()-1"/>
								</xsl:attribute>
								<xsl:if test="SMS &gt; 0">
									<xsl:attribute name="checked">checked</xsl:attribute>
								</xsl:if>
							</input>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose> 
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="SenSet/Delay">
		<tr>
			<xsl:if test="//Agent/Model=4">
				<xsl:attribute name="style">display:none;</xsl:attribute>
			</xsl:if>
			<td><xsl:value-of select="$lg/s[34]"/>:</td>
			<td class="left">
				<input type="text" class="input_text_port" id="SenSetDelay">
					<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
				</input>&#160;<xsl:value-of select="$lg/s[35]"/>
			</td>
			<td>
				<span class="info">
					<xsl:attribute name="title"><xsl:value-of select="$lg/s[226]"/></xsl:attribute>
					?
				</span>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="SenSet" mode="Sensors">
		<xsl:for-each select="Entry"> 
			<tr>
				<td style="text-align:center;">
					<input type="hidden">
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.ID.<xsl:number value="position()-1"/>
						</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="ID"/></xsl:attribute>
					</input>
					<xsl:value-of select="ID"/>
				</td>
				<td class="left">
					<input type="text">
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.Name.<xsl:number value="position()-1"/>
						</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute>
					</input>
				</td>
				<td style="text-align:center;">
					<div>
					  <xsl:apply-templates select="State" mode="MonSenInvInp"/>
						<xsl:value-of select="Value"/>
						<xsl:text> </xsl:text>
						<xsl:apply-templates select="Units"/>
					</div>
				</td>
				<td style="text-align:center;">
					<input type="text" class="input_text_port" style="text-align:right;">
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.Min.<xsl:number value="position()-1"/>
						</xsl:attribute>
						<xsl:attribute name="value"><xsl:value-of select="Min"/></xsl:attribute>
					</input>
					- 
					<input type="text" class="input_text_port" style="text-align:left;">
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.Max.<xsl:number value="position()-1"/>
						</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="Max"/></xsl:attribute>
					</input>
				</td>
				<td style="text-align:center;">
					<input type="checkbox" class="checkbox">
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.Email.<xsl:number value="position()-1"/>
						</xsl:attribute>
						<xsl:if test="Email &gt; 0">
							<xsl:attribute name="checked">checked</xsl:attribute>
						</xsl:if>
					</input>
				</td>
				<td style="text-align:center;">
					<input type="checkbox" class="checkbox">
						<xsl:if test="not(//SMS/E!=0)">
							<xsl:attribute name="disabled">1</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="id">
							<xsl:value-of select="name(..)"/>.SMS.<xsl:number value="position()-1"/>
						</xsl:attribute>
						<xsl:if test="SMS &gt; 0">
							<xsl:attribute name="checked">checked</xsl:attribute>
						</xsl:if>
					</input>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="SoapReport/Alarm">
		<tr>
			<td><xsl:value-of select="$lg/s[39]"/>:</td>
			<td class="left">
				<input type="checkbox" class="checkbox" id="SoapAlarm">
					<xsl:if test=". &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
					<xsl:if test="not(//Soap/Entry[Idx='1']/E &gt; 0)">
						<xsl:attribute name="disabled">disabled</xsl:attribute>
					</xsl:if>
				</input>
			</td>
			<td>
				<span class="info">
					<xsl:attribute name="title"><xsl:value-of select="$lg/s[230]"/></xsl:attribute>
					?
				</span>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="DataLogger/Alarm">
		<tr>
			<td><xsl:value-of select="$lg/s[38]"/>:</td>
			<td class="left">
				<input type="checkbox" class="checkbox" id="LogAlarm">
					<xsl:if test=". &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
			<td>
				<span class="info">
					<xsl:attribute name="title"><xsl:value-of select="$lg/s[229]"/></xsl:attribute>
					?
				</span>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="InverterSet/Delay">
		<tr>
			<td><xsl:value-of select="$lg/s[36]"/>:</td>
			<td class="left">
				<input type="text" class="input_text_port" id="InverterSetDelay">
					<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
				</input>&#160;<xsl:value-of select="$lg/s[35]"/>
			</td>
			<td>
				<span class="info">
					<xsl:attribute name="title"><xsl:value-of select="$lg/s[227]"/></xsl:attribute>
					?
				</span>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="InsolationAlarm/Delay">
		<tr>
			<xsl:if test="//Agent/Model=4">
				<xsl:attribute name="style">display:none;</xsl:attribute>
			</xsl:if>
			<td><xsl:value-of select="$lg/s[37]"/>:</td>
			<td class="left">
				<input type="text" class="input_text_port" id="InsolationAlarmDelay">
					<xsl:attribute name="value"><xsl:value-of select="."/></xsl:attribute>
				</input>&#160;<xsl:value-of select="$lg/s[35]"/>
			</td>
			<td>
				<span class="info">
					<xsl:attribute name="title"><xsl:value-of select="$lg/s[228]"/></xsl:attribute>
					?
				</span>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="InsolationAlarm" mode="Sensors">
		<tr>
			<xsl:if test="//Agent/Model=4">
				<xsl:attribute name="style">display:none;</xsl:attribute>
			</xsl:if>
			<td/>	
			<td class="left">
				<xsl:value-of select="$lg/s[37]"/>
			</td>
			<td style="text-align:center;">
				<xsl:apply-templates select="State" mode="MonSenInvInp"/>
				<xsl:apply-templates select="." mode="Common"/>
			</td>
			<td style="text-align:center;">
				<xsl:value-of select="$lg/s[46]"/>:  
				<input type="text" style="width:3em;text-align:right;" maxlength="6" id="CompareValue">
					<xsl:attribute name="value"><xsl:value-of select="CompareValue"/></xsl:attribute>
				</input>
				W/m2
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox" id="InsolationAlarmEmail"> 
					<xsl:if test="Email &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox" id="InsolationAlarmSMS">
					<xsl:if test="not(//SMS/E!=0)">
						<xsl:attribute name="disabled">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="SMS &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
		</tr>
	</xsl:template>

 	<xsl:template match="PeriodicalInfo" mode="Sensors">
		<tr>
			<td/>	
			<td class="left">
				<xsl:value-of select="$lg/s[66]"/>
			</td>
			<td style="text-align:center;">
				<select id="Period">
					<option value="0">
						<xsl:if test="Period=0">
							<xsl:attribute name="selected">selected</xsl:attribute>                                                                                                                                                                                                             
						</xsl:if>
						<xsl:value-of select="$lg/s[67]"/>
					</option>
					<option value="1">
						<xsl:if test="Period=1">
							<xsl:attribute name="selected">selected</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="$lg/s[68]"/>
					</option>
				</select>
			</td>
			<td style="text-align:center;">
				<xsl:value-of select="$lg/s[69]"/>: 
				<input type="text" style="width:1.4em;text-align:right;" maxlength="2" id="Hour">
					<xsl:attribute name="value"><xsl:value-of select="Hour"/></xsl:attribute>
				</input>
				:00
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox" id="PeriodicalInfoEmail"> 
					<xsl:if test="Email &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
			<td style="text-align:center;">
				<input type="checkbox" class="checkbox" id="PeriodicalInfoSMS">
					<xsl:if test="not(//SMS/E!=0)">
						<xsl:attribute name="disabled">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="SMS &gt; 0">
						<xsl:attribute name="checked">checked</xsl:attribute>
					</xsl:if>
				</input>
			</td>
		</tr>
  </xsl:template>
</xsl:stylesheet>

