<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sts="http://www.etech.cz/XMLSchema/sim/stats.xsd">

	<xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

	<xsl:include href="template.xsl"/>

	<xsl:template match="sts:Root">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="index.css" />
				<script type="text/javascript" src="setup.js"></script>
				<title><xsl:call-template name="title"/></title>
			</head>
			<body >
				<div id="container">
					<div id="min_height"></div>
					<div id="sidebar">
						<div id="sidebar-content">
							<div id="logo">
								<div id="logo_trans"/>
							</div>
							<div id="menu">
								<xsl:apply-templates select="Agent/Menu"/>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
					<div id="main-div">
						<div id="main-content">
							<div id="top_area">
							  <div id="dev_name"><xsl:value-of select="Agent/DeviceName"/></div>
							  <div id="caption"><xsl:value-of select="$lg/s[6]"/></div>
							</div>
							<div id="content">
								<div class="column_left">
									<xsl:apply-templates select="Stats/Entry[4]"/>
								</div>
								<div class="column_right">
									<xsl:apply-templates select="Stats/Entry[3]"/>
								</div>
								<div class="column_left">
									<xsl:apply-templates select="Stats/Entry[2]"/>
								</div>
								<div class="column_right">
									<xsl:apply-templates select="Stats/Entry[1]"/>
								</div>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
				</div>    
				<div id="bottom-contact">
					<xsl:apply-templates select="Agent/Contact"/>
				</div>
			</body>
		</html>
	</xsl:template>

	<!-- TEMPLATE -->
	
	<xsl:template match="Stats/Entry">
		<xsl:variable name="max">
			<xsl:for-each select="Months/Val">
				<xsl:sort data-type="number" order="descending"/>
				<xsl:if test="position()=1">
					<xsl:value-of select="."/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<h1><xsl:value-of select="$lg/s[170]"/>&#160;<xsl:value-of select="Name"/> (<xsl:value-of select="$lg/s[169]"/>&#160;<xsl:value-of select="floor(sum((Months/Val)) div(100)) div(10)"/> kWh)</h1>
		<table class="tbl_half">
			<xsl:for-each select="Months/Val">
				<tr>
					<td>
						<xsl:if test="position()=1"><xsl:value-of select="$lg/s[171]"/></xsl:if>
						<xsl:if test="position()=2"><xsl:value-of select="$lg/s[172]"/></xsl:if>
						<xsl:if test="position()=3"><xsl:value-of select="$lg/s[173]"/></xsl:if>
						<xsl:if test="position()=4"><xsl:value-of select="$lg/s[174]"/></xsl:if>
						<xsl:if test="position()=5"><xsl:value-of select="$lg/s[175]"/></xsl:if>
						<xsl:if test="position()=6"><xsl:value-of select="$lg/s[176]"/></xsl:if>
						<xsl:if test="position()=7"><xsl:value-of select="$lg/s[177]"/></xsl:if>
						<xsl:if test="position()=8"><xsl:value-of select="$lg/s[178]"/></xsl:if>
						<xsl:if test="position()=9"><xsl:value-of select="$lg/s[179]"/></xsl:if>
						<xsl:if test="position()=10"><xsl:value-of select="$lg/s[180]"/></xsl:if>
						<xsl:if test="position()=11"><xsl:value-of select="$lg/s[181]"/></xsl:if>
						<xsl:if test="position()=12"><xsl:value-of select="$lg/s[182]"/></xsl:if>
					</td>
					<td style="text-align: right;">
						<xsl:if test=".>1000000000">
							<xsl:value-of select="floor(. div(100000))div(10)"/> MWh
						</xsl:if>
						<xsl:if test="1000000000>=.">
							<xsl:value-of select="floor(. div(100))div(10)"/> kWh
						</xsl:if>
					</td>
					<td width="170px">
						<table width="170px" style="border:0;">
							<tr class="EmptyRow">
								<td onmouseover="this.style.background = '#f90'" onmouseout="this.style.background = '#fec'" style="background:#fec; border-top: solid 1px #f90; border-bottom: solid 1px #f90; border-right: solid 1px #f90;">
									<xsl:attribute name="width">
										<xsl:if test="($max div 100) >= .">
											1px
										</xsl:if>
										<xsl:if test=".>1">
											<xsl:value-of select="((. div $max) * 100)"/>
										</xsl:if>
										%
									</xsl:attribute>
								</td>
								<td>
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
</xsl:stylesheet>
