<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:inv="http://www.etech.cz/XMLSchema/sim/invoices.xsd">

	<xsl:output method="html" encoding="UTF-8" indent="no"
              doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
              doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

	<xsl:include href="template.xsl"/>

	<xsl:template match="inv:Root">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="index.css" />
				<script type="text/javascript" src="setup.js"></script>
				<title><xsl:call-template name="title"/></title>
			</head>
			<body>
				<div id="container">
					<div id="min_height"></div>
					<div id="sidebar">
						<div id="sidebar-content">
							<div id="logo">
								<div id="logo_trans"/>
							</div>
							<div id="menu">
								<xsl:apply-templates select="Agent/Menu"/>
							</div>
							<div id="submit_area">
								<input type="button" class="input_auto" value="Uložit změny" onClick="setVykCfg();"/>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
					<div id="main-div">
						<div id="main-content">
							<div id="top_area">
							  <div id="dev_name"><xsl:apply-templates select="Agent/DeviceName"/></div>
							  <div id="caption">Nastavení výkazu</div>
							</div>
							<div id="content">
								<div class="column_left">
									<xsl:apply-templates select="Report" mode="Info"/>
								</div>
								<div class="column_right">
									<xsl:apply-templates select="Report" mode="Param"/>
									<xsl:apply-templates select="Report" mode="Issue"/>
									<p class="right">
									<input type="button" class="input_auto" value="Náhled výkazu" onClick="openWindow('report_t.xml', 'Nahled_vykaz');"/>
									</p>
								</div>
							</div>
							<hr class="cleaner" />
						</div>
					</div>
				</div>       
				<div id="bottom-contact">
					<xsl:apply-templates select="Agent/Contact"/>
				</div>
			</body>
		</html>
	</xsl:template>

	<!-- TEMPLATE -->

	<xsl:template match="Report" mode="Info">
  	<h1>Informace o výrobně</h1>
		<p>
			<table class="tbl_half">
				<colgroup>
				  <col class="col_name_middle"/>
				  <col class="col_value"/>
				  <col class="col_help"/>
				</colgroup>
			<tbody>
				  <tr>
						<td>Název výrobny</td>
						<td><input type="text" id="Name"><xsl:attribute name="value"><xsl:value-of select="Name"/></xsl:attribute></input></td>
						<td>					
							<span class="info" title="Název provozovny dle rozhodnutí ERÚ o udělení licence">?</span>
						</td>

				  </tr>
				  <tr>
						<td>Výrobna - ulice</td>
						<td><input type="text" id="Street"><xsl:attribute name="value"><xsl:value-of select="Street"/></xsl:attribute></input></td>
						<td/>
				  </tr>
				  <tr>
						<td>Výrobna - město</td>
						<td><input type="text" id="Town"><xsl:attribute name="value"><xsl:value-of select="Town"/></xsl:attribute></input></td>
						<td/>
				  </tr>
				  <tr>
						<td>Výrobna - kraj</td>
						<td><input type="text" id="Province"><xsl:attribute name="value"><xsl:value-of select="Province"/></xsl:attribute></input></td>
						<td>					
							<span class="info" title="Včetně slova 'kraj' nebo 'Hlavní město'">?</span>
						</td>

				  </tr>
				  <tr>
						<td>Výrobna - PSČ</td>
						<td><input type="text" id="ZIP"><xsl:attribute name="value"><xsl:if test="ZIP!=0"><xsl:value-of select="ZIP"/></xsl:if></xsl:attribute></input></td>
						<td/>

				  </tr>
				  <tr>
						<td>Číslo licence na výrobu</td>
						<td><input type="text" id="License"><xsl:attribute name="value"><xsl:value-of select="License"/></xsl:attribute></input></td>
						<td/>
				  </tr>
				  <tr>
						<td>Druh OZE</td>
						<td>				
							<select id="Type">
								<option value="0">
								  <xsl:if test="Type=0">
										<xsl:attribute name="selected">selected</xsl:attribute>
								  </xsl:if>
								  Fotovoltaická el.
								</option>
							</select>
						</td>
						<td/>
				  </tr>
				  <tr>
						<td>Datum zprovoznění</td>
						<td>
							<input type="text" class="input_text_date" id="Date" onclick="displayDatePicker(this.id);" onchange="manualyModified(this.id)">
								<xsl:attribute name="value"><xsl:value-of select="Date"/></xsl:attribute>
							</input>
						</td>
						<td/>
				  </tr>
        </tbody>
      </table>
    </p>
  </xsl:template>
  
	<xsl:template match="Report" mode="Param">
	<h1>Parametry výrobny</h1>
		<p>
			<table class="tbl_half">
				<colgroup>
					<col class="col_name_middle"/>
					<col class="col_value"/>
					<col class="col_help"/>
				</colgroup>
			<tbody>
				<tr>
					<td>Napětí v místě předání</td>
					<td>
						<input type="text" maxlength="7" id="Voltage" class="input_text_date"><xsl:attribute name="value"><xsl:value-of select="Voltage div 10"/></xsl:attribute></input>V
					</td>
					<td/>
				</tr>
				<tr>
					<td>Označení dle smlouvy</td>
					<td>
						<input type="text" id="Commit"><xsl:attribute name="value"><xsl:value-of select="Commit"/></xsl:attribute></input>
					</td>
					<td>
						<span class="info" title="Označení předávacího místa podle smlouvy o připojení">?</span>
					</td>
				</tr>
			</tbody>
		</table>
	</p>
</xsl:template> 
	
	<xsl:template match="Report" mode="Issue"> 
  	<h1>Výkaz</h1>
    <p>
			<table class="tbl_half">
        <colgroup>
          <col class="col_name_middle"/>
          <col class="col_value"/>
        </colgroup>
        <tbody>
				  <tr>
						<td>Vystaven v</td>
						<td><input type="text" id="IssueTown"><xsl:attribute name="value"><xsl:value-of select="IssueTown"/></xsl:attribute></input></td>
				  </tr>
				  <tr>
						<td>Vystavil</td>
						<td><input type="text" id="Issuer"><xsl:attribute name="value"><xsl:value-of select="Issuer"/></xsl:attribute></input></td>
				  </tr>
				  <tr>
						<td>Výkaz o výrobě dle</td>
						<td>
							<select id="Version">
								<option value="3">
								  <xsl:if test="Version=3">
										<xsl:attribute name="selected">selected</xsl:attribute>
								  </xsl:if>
								  468/2009 Sb. (13 ř.)
								</option>
								<option value="2">
								  <xsl:if test="Version=2">
										<xsl:attribute name="selected">selected</xsl:attribute>
								  </xsl:if>
								  365/2007 Sb. (12 ř.)	
								</option>
								<option value="1">
								  <xsl:if test="Version=1">
										<xsl:attribute name="selected">selected</xsl:attribute>
								  </xsl:if>
								  541/2005 Sb. (10 ř.)	
								</option>
								<option value="0">
								  <xsl:if test="Version=0">
										<xsl:attribute name="selected">selected</xsl:attribute>
								  </xsl:if>
								  PRE do roku 2010 (6 ř.)	
								</option>
							</select>
						</td>
				  </tr>
        </tbody>
      </table>
    </p>
  </xsl:template>
</xsl:stylesheet>

